import React, { useEffect, useState } from "react";
import { postFxTenant, putFxTenant, getFxTenantId } from "@/services/fxtenant";
import { useNavigate, useSearchParams } from "react-router-dom";
import {
  ProForm,
  ProFormText,
  ProFormDateRangePicker,
  ProFormSelect,
} from "@ant-design/pro-components";
import { Card, Form, Row, Col, Button, DatePicker, Select } from "antd";
import Page from "@/components/Page";
import { formItemLayout, tailFormItemLayout } from "@/utils/form";
import moment from "moment";

const dateFormat = "YYYY-MM-DD";

export default (props) => {
  const formRef = React.useRef();
  const navigate = useNavigate();
  const [searchParams] = useSearchParams();
  const id = searchParams.get("id");
  useEffect(() => {
    formRef.current?.resetFields();
    if (id) {
      getFxTenantId(id).then((res) => {
        formRef.current?.setFieldsValue({
          ...res,
          time: [
            moment(res.startTime, dateFormat),
            moment(res.endTime, dateFormat),
          ],

        });
      });
    }
  }, []);

  const onFinish = (x) => {
    formRef.current?.validateFieldsReturnFormatValue?.().then((values) => {
      console.log("values", values);
      const data = {
        ...values,
        startTime: values?.time[0],
        endTime: values?.time[1],
      };
      const tenantId = id;
      if (!tenantId) {
        postFxTenant(data).then((res) => {
          navigate(-1);
        });
      } else {
        putFxTenant(tenantId, { tenantId, ...data }).then((res) => {
          navigate(-1);
        });
      }
    });
  };

  return (
    <Page>
      <Card>
        <ProForm
          formRef={formRef}
          onFinish={onFinish}
          layout="horizontal"
          {...formItemLayout}
          submitter={{
            render: (_, doms) => [
              <Row>
                <Col offset={8}>
                  <Button type="primary" htmlType="submit">
                    提交
                  </Button>
                </Col>
                <Col offset={1}>
                  <Button onClick={() => navigate(-1)}>返回</Button>
                </Col>
              </Row>,
            ],
          }}
        >
          <ProFormText
            name="tenantName"
            label="租户名称"
            placeholder="请输入租户名称"
            rules={[{ required: true, message: "租户名称不能为空" }]}
          />
          <Form.Item
            name={["time"]}
            label="合同生效时间"
            rules={[{ required: true, message: "合同生效时间不能为空" }]}
          >
            <DatePicker.RangePicker />
          </Form.Item>

          <ProFormText
            name="manager"
            label="管理员名称"
            placeholder="请输入管理员名称"
          />
          <ProFormText
            name="phone"
            label="手机号(租户账号)"
            placeholder="请输入手机号"
            rules={[{ required: true, message: "手机号不能为空" }]}
          />
          <ProFormSelect
            label="状态"
            name="status"
            options={[
              { label: '未激活', value: 0 },
              { label: '已激活', value: 1 },
              { label: '停用', value: 2 }
            ]}
          />
        </ProForm>
      </Card>
    </Page>
  );
};
