import List from "@/components/Page/List";
import React from "react";

import { getFxTenant, deleteFxTenant } from "@/services/fxtenant";

import { useNavigate } from "react-router-dom";
import { Button, Typography } from "antd";
import moment from "moment";
export default (props) => {
  const { Text } = Typography;
  const navigate = useNavigate();
  const actionRef = React.useRef();

  const columns = [
    {
      title: "时间",
      dataIndex: "time",
      valueType: "dateRange",
      hideInTable: true,
      search: {
        transform: (value) => {
          return {
            startTime: value[0],
            endTime: value[1],
          };
        },
      },
    },
    {
      title: "租户名称",
      dataIndex: "tenantName",
    },
    {
      title: "开始时间",
      dataIndex: "startTime",
      render: (t) => moment(t).format("YYYY-MM-DD"),
      search: false,
    },
    {
      title: "结束时间",
      dataIndex: "endTime",
      render: (t) => moment(t).format("YYYY-MM-DD"),
      search: false,
    },
    {
      title: "管理人名称",
      dataIndex: "manager",
      search: false,
    },
    {
      title: "手机号",
      dataIndex: "phone",
    },
    {
      title: "登录地址",
      dataIndex: "tenantId",
      render: (_, record) => {
        const url = `${import.meta.env.VITE_LOGIN_URL}#/${record.tenantId}/login`
        console.log(url)
        return <Text copyable={{ text: url }} ellipsis={true}>{url}</Text>;
      },
      search: false,
    },
    {
      title: "状态",
      dataIndex: "status",
      valueType: "select",
      render: (_, record) =>
        record.status == 0 ? "未激活" : record.status == 1 ? "已激活" : "停用",
      valueEnum: {
        0: "未激活",
        1: "已激活",
        2: "停用",
      },
    }
  ];

  const DeleteFxUser = (record) => {
    deleteFxTenant(record.tenantId).then((res) => {
      actionRef.current.reload();
    });
  };


  return (
    <List
      rowKey="tenantId"
      actionRef={actionRef}
      request={getFxTenant}
      onEdit={(record) => navigate(`/tenant/edit?id=${record.tenantId}`)}
      onDelete={DeleteFxUser}
      toolBarRender={() => [
        <Button
          key="1"
          type="primary"
          onClick={() => {
            navigate("edit");
          }}
        >
          新增
        </Button>,
      ]}
      columnOptionRender={(_, record) => [
        <a href={`${import.meta.env.VITE_LOGIN_URL}#/${record.tenantId}/login`} target='_blank'>登录</a>
      ]}
      columns={columns}
    />
  );
};
