import {
  UserOutlined,
  SolutionOutlined,
  FileTextOutlined,
  CreditCardOutlined,
  IdcardOutlined,
} from "@ant-design/icons";
import { Outlet, Navigate } from "react-router-dom";
import AuthLayout from "@/layouts/AuthLayout";
import Login from "@/pages/login";
import Page404 from "@/pages/404";
import Authentication from "@/pages/authentication";
import HomePage from "@/pages/homepage";
import AccountManagement from "@/pages/accountmanagement";
import QuickPass from "@/pages/quickpass";
import FinancialStatement from "@/pages/financialstatement";
import Incorporation from "@/pages/incorporation";
import EcologicalPartner from "@/pages/ecologicalpartner";
import AccountSettings from "@/pages/accountsettings";
import PayMent from "@/pages/payment";
import RecipientManagement from "@/pages/recipientmanagement";
import StoreForeignExchange from "@/pages/storeforeignexchange";
import QuantuMstored from "@/pages/quantumstored";
import QuantumCredit from "@/pages/quantumcredit";
import TransactionInquiry from "@/pages/transactioninquiry";
import FirstPage from "@/pages/firstPage/index";

import QLogin from "@/pages/qLogin/index";
import QRegister from "@/pages/qRegister/index";

/**
 * meta 用来扩展自定义数据数据
 * {
 *    title: 用于页面或者菜单的标题, 没有此字段, 菜单不会显示
 *    hideInMenu: 布尔值, 如果为 false, 菜单不会显示
 *    noLayout: 布尔值, 如果为 true, 将不会使用默认布局
 *    noSiderBar: 布尔值, 如果为 true, 将没有左侧菜单栏
 *    noFooter: 布尔值, 如果为 true, 将没有底部 footer
 *    target: 字符串, 如果为 _blank, 将在新窗口打开
 *    permission: 对应服务器端权限名称
 * }
 */

export const authRoutes = [
  {
    // index: true,
    element: <Navigate to="/homepage" />,
  },
  // 实名认证流程
  {
    path: "/authentication",
    element: <Authentication />,
    meta: {
      title: "",
      hideInMenu: true
    },
  },
  {
    path: "homepage",
    element: <HomePage />,
    meta: {
      title: "首页",
      icon: <SolutionOutlined />,
    },
  },
  {
    path: "/globalaccounts",
    element: <Outlet />,
    meta: {
      title: "全球账户",
      icon: <IdcardOutlined />,
    },
    children: [
      {
        path: "accountmanagement",
        element: <AccountManagement />,
        meta: {
          title: "账户管理",
          icon: <SolutionOutlined />,
        },
      },
      {
        path: "payment",
        element: <PayMent />,
        meta: {
          title: "付款",
          icon: <SolutionOutlined />,
        },
      },
      {
        path: "recipientmanagement",
        element: <RecipientManagement />,
        meta: {
          title: "收款方管理",
          icon: <SolutionOutlined />,
        },
      },
      {
        path: "storeforeignexchange",
        element: <StoreForeignExchange />,
        meta: {
          title: "店铺和结汇额度管理",
          icon: <SolutionOutlined />,
        },
      },
    ],
  },
  // {
  //   path: "quantum",
  //   element: <Outlet />,
  //   meta: {
  //     title: "量子卡",
  //     icon: <CreditCardOutlined />,
  //   },
  //   children: [
  //     {
  //       path: "quantumstored",
  //       element: <QuantuMstored />,
  //       meta: {
  //         title: "量子储值卡",
  //       },
  //     },
  //     {
  //       path: "quantumcredit",
  //       element: <QuantumCredit />,
  //       meta: {
  //         title: "量子额度卡",
  //       },
  //     }, {
  //       path: "transactioninquiry",
  //       element: <TransactionInquiry />,
  //       meta: {
  //         title: "交易查询",
  //       },
  //     },
  //   ],
  // },
  {
    path: "quickpass",
    element: <QuickPass />,
    meta: {
      title: "闪付",
      icon: <SolutionOutlined />,
    },
  },
  {
    path: "financialstatement",
    element: <FinancialStatement />,
    meta: {
      title: "财务对账单",
      icon: <SolutionOutlined />,
    },
  },
  {
    path: "incorporation",
    element: <Incorporation />,
    meta: {
      title: "公司注册",
      icon: <SolutionOutlined />,
    },
  },
  // {
  //   path: "ecologicalpartner",
  //   element: <EcologicalPartner />,
  //   meta: {
  //     title: "生态伙伴",
  //     icon: <SolutionOutlined />,
  //   },
  // },
  {
    path: "accountsettings",
    element: <AccountSettings />,
    meta: {
      title: "账号设置",
      icon: <SolutionOutlined />,
    },
  },
];

export const defaultRoutes = [
  {
    path: "/",
    element: <AuthLayout />,
    children: [
      {
        path: "*",
        element: <Page404 />,
      },
    ],
  },
  {
    path: "/firstPage",
    element: <FirstPage />,
  },
  // q登录页
  {
    path: "/qLogin",
    element: <QLogin />,
  },
  // q注册页
  // {
  //   path: "/qRegister",
  //   element: <QRegister />,
  // },
  // {
  //   path: "/login",
  //   element: <Login />,
  // },
  {
    path: "*",
    element: <Page404 />,
  },
];

export function mergeAuthRoutes (r1, r2) {
  const r = r1.slice();
  const children = r1[0].children.slice();
  r[0].children = children.concat(r2);
  return r;
}

// 全部路由
export const routes = mergeAuthRoutes(defaultRoutes, authRoutes);
console.log(routes);
function getPath (parent = "/", current = "") {
  if (current.indexOf("/") === 0 || current.indexOf("http") === 0)
    return current;
  return `${parent}/${current}`.replace(/\/\//g, "/");
}

// 路由数组, 一维数组
export const routeArr = (() => {
  const flatten = (routes, parentPath = "/") => {
    return routes.reduce((acc, route) => {
      const path = getPath(parentPath, route.path);
      const children = route.children ? flatten(route.children, path) : [];

      return acc.concat([{ ...route, path }].concat(children));
    }, []);
  };

  return flatten(routes);
})();
